@@ -1,4 +1,5 @@
 import sys, os, errno, subprocess
+from runProcess import runProcess
 
 def makeFolder(path):
     """Attempts folder creation
@@ -15,9 +16,11 @@ def makeFolder(path):
 class Vina(object):
 	"""Vina driver. Sets up locations of files. """
 
-	def __init__(self, screen, cmpnd):
+	def __init__(self, screen, cmpnd, verbose = False):
 		self.locations = {}
 		self.screen = screen
+		self.cmd = runProcess()
+		self.cmd.verbose = verbose
 
 		if 'linux' in sys.platform:
 			self.locations['vina'] = screen.protocol_dir + "/OpenDiscovery/lib/vina-linux/vina"
@@ -27,15 +30,15 @@ class Vina(object):
 		self.locations['receptor'] = screen.ligand_dir + "/receptor/" + screen.options['receptor'] + ".pdbqt"
 		self.locations['ligand'] = screen.ligand_dir + "/ligands/" + cmpnd + ".pdbqt"
 		self.locations['config'] = screen.ligand_dir + "/receptor/" + screen.options['receptor'] + ".txt"
-		self.locations['results'] = screen.ligand_dir + "/results/" + cmpnd + ".pdbqt"
-		self.locations['log'] = screen.ligand_dir + "/results/" + cmpnd + ".txt"
+		self.locations['results'] = screen.ligand_dir + "/results-"+screen.options['receptor']+"/" + cmpnd + ".pdbqt"
+		self.locations['log'] = screen.ligand_dir + "/results-"+screen.options['receptor']+"/" + cmpnd + ".txt"
 
-		makeFolder(screen.ligand_dir + "/results")
+		makeFolder(screen.ligand_dir + "/results-"+screen.options['receptor'])
 
 	def run(self):
 		""" Actually calls the vina binary. """
 
-		subprocess.call('{vina} --receptor {receptor} --ligand {ligand} --config {conf} --out {results} --log {log} --exhaustiveness {exhaustiveness}'.format(
+		self.cmd.run('{vina} --receptor {receptor} --ligand {ligand} --config {conf} --out {results} --log {log} --exhaustiveness {exhaustiveness}'.format(
 			vina=self.locations['vina'], receptor=self.locations['receptor'], ligand=self.locations['ligand'],
 			conf=self.locations['config'], results=self.locations['results'], log=self.locations['log'],
-			exhaustiveness=self.screen.options['exhaustiveness']), stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
\ No newline at end of file
+			exhaustiveness=self.screen.options['exhaustiveness']))
\ No newline at end of file
